@@ -131,6 +131,9 @@ class Worker:
                 self._process()
 
             await self.event.wait()
+
+            for signum in self.SIGNALS:
+                loop.remove_signal_handler(signum)
         finally:
             logger.info("Shutting down")
 
@@ -237,14 +240,14 @@ class Worker:
             job.status = Status.ACTIVE
             job.attempts += 1
             await job.update()
-            context = {"worker": self, "job": job}
+            context = {**self.context, "job": job}
             await self._before_process(context)
             logger.info("Processing %s", job)
 
             function = ensure_coroutine_function(self.functions[job.function])
             task = asyncio.create_task(function(context, **(job.kwargs or {})))
             self.job_task_contexts[job] = {"task": task, "aborted": False}
-            result = await asyncio.wait_for(task, job.timeout)
+            result = await asyncio.wait_for(task, job.timeout if job.timeout else None)
             await job.finish(Status.COMPLETE, result=result)
         except asyncio.CancelledError:
             if job and not self.job_task_contexts.get(job, {}).get("aborted"):
